ChannelTalkFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ChannelTalkFlutterPlatform
Implementers

Constructors

ChannelTalkFlutterPlatform()
Constructs a ChannelTalkFlutterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTags(List tags) → Future<bool?>
boot(Map<String, dynamic> config) → Future<bool?>
hasStoredPushNotification() → Future<bool?>
hideChannelButton() → Future<bool?>
hideMessenger() → Future<bool?>
hidePopup() → Future<bool?>
initPushToken(String deviceToken) → Future<bool?>
isBooted() → Future<bool?>
isChannelPushNotification(Map<String, dynamic> content) → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openChat({String? chatId, String? message}) → Future<bool?>
openStoredPushNotification() → Future<bool?>
openWorkflow({String? workflowId}) → Future<bool?>
receivePushNotification(Map<String, dynamic> content) → Future<bool?>
removeListener() → void
removeTags(List tags) → Future<bool?>
resetPage() → Future<bool?>
setAppearance(Appearance appearance) → Future<bool?>
setDebugMode(bool flag) → Future<bool?>
setListener(ChannelTalkDelegate delegate) → void
setPage(String page) → Future<bool?>
setPreventDefaultUrlClick(bool prevent) → Future<bool?>
showChannelButton() → Future<bool?>
showMessenger() → Future<bool?>
shutdown() → Future<bool?>
sleep() → Future<bool?>
storePushNotification(Map<String, dynamic> content) → Future<bool?>
toString() → String
A string representation of this object.
inherited
track({required String eventName, Map<String, dynamic>? properties}) → Future<bool?>
updateUser(Map<String, dynamic> data) → Future<bool?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ChannelTalkFlutterPlatform
The default instance of ChannelTalkFlutterPlatform to use.
getter/setter pair