ChannelTalkFlutterWeb class

A web implementation of the ChannelTalkFlutterPlatform of the ChannelTalkFlutter plugin.

Inheritance

Constructors

ChannelTalkFlutterWeb()
Constructs a ChannelTalkFlutterWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTags(List tags) → Future<bool?>
override
boot(Map<String, dynamic> config) → Future<bool?>
override
hasStoredPushNotification() → Future<bool?>
inherited
hideChannelButton() → Future<bool?>
override
hideMessenger() → Future<bool?>
override
hidePopup() → Future<bool?>
inherited
initPushToken(String deviceToken) → Future<bool?>
inherited
isBooted() → Future<bool?>
inherited
isChannelPushNotification(Map<String, dynamic> content) → Future<bool?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openChat({String? chatId, String? message}) → Future<bool?>
override
openStoredPushNotification() → Future<bool?>
inherited
openWorkflow({String? workflowId}) → Future<bool?>
override
receivePushNotification(Map<String, dynamic> content) → Future<bool?>
inherited
removeListener() → void
inherited
removeTags(List tags) → Future<bool?>
override
resetPage() → Future<bool?>
override
setAppearance(Appearance appearance) → Future<bool?>
override
setDebugMode(bool flag) → Future<bool?>
inherited
setListener(ChannelTalkDelegate delegate) → void
inherited
setPage(String page) → Future<bool?>
override
setPreventDefaultUrlClick(bool prevent) → Future<bool?>
inherited
showChannelButton() → Future<bool?>
override
showMessenger() → Future<bool?>
override
shutdown() → Future<bool?>
override
sleep() → Future<bool?>
inherited
storePushNotification(Map<String, dynamic> content) → Future<bool?>
inherited
toString() → String
A string representation of this object.
inherited
track({required String eventName, Map<String, dynamic>? properties}) → Future<bool?>
override
updateUser(Map<String, dynamic> data) → Future<bool?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void